@@ -60,8 +60,12 @@ def blog_months(*args):
     """
     Put a list of dates for blog posts into the template context.
     """
-    return list(BlogPost.objects.published().dates("publish_date", "month",
-                                                   order="DESC"))
+    months = []
+    for month in BlogPost.objects.published().dates("publish_date", "month",
+                                                    order="DESC"):
+        if month not in months:
+            months.append(month)
+    return months
 
 
 @register.as_tag
@@ -70,7 +74,7 @@ def blog_categories(*args):
     Put a list of categories for blog posts into the template context.
     """
     posts = BlogPost.objects.published()
-    return list(BlogCategory.objects.filter(blogposts__in=posts))
+    return list(BlogCategory.objects.filter(blogposts__in=posts).distinct())
 
 
 @register.as_tag
@@ -107,6 +111,14 @@ def blog_authors(*args):
     return list(User.objects.filter(blogposts__in=blog_posts).distinct())
 
 
+@register.as_tag
+def blog_recent_posts(limit=5):
+    """
+    Put a list of recently published blog posts into the template context.
+    """
+    return list(BlogPost.objects.published()[:limit])
+
+
 @register.inclusion_tag("admin/includes/quick_blog.html", takes_context=True)
 def quick_blog(context):
     """
